==> sbSortedLogistics_1.0.11.zip: sbSortedLogistics_1.0.11/faq.md <==
# FAQ #

---
**Q**: The sorting gui disappeared, where is it?  
**A**: This can have multiple causes.

- You closed a gui and the state of the now current gui can not be determined.  
  Close and reopen the object.
- The foreground gui may be bigger now (mods,scaling,etc).  
  Move the foreground gui around to see if the sorting gui is hidden behind it.
- Changes to screen resolution or scaling may have pushed the sorting gui outside the screen.  
  Open the console (usually "^", top left of your keyboard below "ESC") and enter the command "`/sortme reset`".

---
**Q**: Your sorting order sucks, can we have some alternatives please?  
**A**: Since inventories (and books also count as inventories) have their integrated [sort_and_merge][] function, i am somewhat reluctant to build my own.  
 My sorting functions also try to create the same order as the crafting menu, item select menu and inventories.  
 If you think you have a better sorting order, try to convince me in the [discussions][discussion].

---
**Q**: Can you please also sort X?  
**A**: That is absolutely definitively a maybe.  
 While my mod should handle everything vanilla factorio has to offer, i can't promise that i did not overlook anything.  
 But factorio gives modders a whole toolbox with goodies to play shenanigans with. So i am sure there are some mods out there with stuff i could sort.  
 If you find such a mod, [request][discussion] a sort button and i add it if i can.

---
**Q**: I got the message that your mod is malfunctioning. What does that mean?  
**A**: Instead of halting the game my mod tries to "gracefully" [ignore errors][pcall]. If this happens only once and you have no idea why, you can _probably_ ignore that. But i would be happy if you filed a [bug report][discussion] regardless.  
 If that message is a regular occurrence you should definitely write a [bug report][discussion], because you or a mod you use does something i have not accounted for. or i forgot something.

---
**Q**: Fine, i'll write you a bug report. What do you need?  
**A**: A description of the error, preferably with exact steps to reproduce, be as detailed as possible please.



[discussion]: https://mods.factorio.com/mod/sbSortedLogistics/discussion
[sort_and_merge]: https://lua-api.factorio.com/latest/classes/LuaInventory.html#sort_and_merge
[pcall]: https://www.lua.org/manual/5.2/manual.html#pdf-pcall
[user_data_directory]: https://wiki.factorio.com/User_data_directory

==> sbSortedLogistics_1.0.12_dev.zip: sbSortedLogistics_1.0.12/faq.md <==
# FAQ #

---
**Q**: The sorting gui disappeared, where is it?  
**A**: This can have multiple causes.

- You closed a gui and the state of the now current gui can not be determined.  
  Close and reopen the object.
- The foreground gui may be bigger now (mods,scaling,etc).  
  Move the foreground gui around to see if the sorting gui is hidden behind it.
- Changes to screen resolution or scaling may have pushed the sorting gui outside the screen.  
  Open the console (usually "^", top left of your keyboard below "ESC") and enter the command "`/sortme reset`".

---
**Q**: I activated automatic sorting for X, but it does not get sorted when i open X?  
**A**: Automatic sorting relies entirely on your per player setting options. You need to enable autosort as a whole and also which things should be sorted.  
 After loading an older savegame the shortcut button may display the wrong autosort state. Clicking the button twice will rectify this.  
 The sorting gui should properly sync with your per player setting options.

---
**Q**: Your sorting order sucks, can we have some alternatives please?  
**A**: Since inventories (and books also count as inventories) have their integrated [sort_and_merge][] function, i am somewhat reluctant to build my own.  
 My sorting functions also try to create the same order as the crafting menu, item select menu and inventories.  
 If you think you have a better sorting order, try to convince me in the [discussions][discussion].

---
**Q**: Can you please also sort X?  
**A**: That is absolutely definitively a maybe.  
 While my mod should handle everything vanilla factorio has to offer, i can't promise that i did not overlook anything.  
 But factorio gives modders a whole toolbox with goodies to play shenanigans with. So i am sure there are some mods out there with stuff i could sort.  
 If you find such a mod, [request][discussion] a sort button and i add it if i can.

---
**Q**: I got the message that your mod is malfunctioning. What does that mean?  
**A**: Instead of halting the game my mod tries to "gracefully" [ignore errors][pcall]. If this happens only once and you have no idea why, you can _probably_ ignore that. But i would be happy if you filed a [bug report][discussion] regardless.  
 If that message is a regular occurrence you should definitely write a [bug report][discussion], because you or a mod you use does something i have not accounted for. or i forgot something.

---
**Q**: Fine, i'll write you a bug report. What do you need?  
**A**: A description of the error, preferably with exact steps to reproduce, be as detailed as possible please.



[discussion]: https://mods.factorio.com/mod/sbSortedLogistics/discussion
[sort_and_merge]: https://lua-api.factorio.com/latest/classes/LuaInventory.html#sort_and_merge
[pcall]: https://www.lua.org/manual/5.2/manual.html#pdf-pcall
[user_data_directory]: https://wiki.factorio.com/User_data_directory
